/*
 * Copyright 2010-2012 Luca Garulli (l.garulli--at--orientechnologies.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.orientechnologies.orient.server.network.protocol.http.command.delete;

import com.orientechnologies.orient.core.db.ODatabaseComplex;
import com.orientechnologies.orient.core.db.document.ODatabaseDocumentTx;
import com.orientechnologies.orient.server.OServerMain;
import com.orientechnologies.orient.server.network.protocol.http.OHttpRequest;
import com.orientechnologies.orient.server.network.protocol.http.OHttpUtils;
import com.orientechnologies.orient.server.network.protocol.http.command.OServerCommandAuthenticatedServerAbstract;

public class OServerCommandDeleteDatabase extends OServerCommandAuthenticatedServerAbstract {
  private static final String[] NAMES = { "DELETE|database/*" };

  public OServerCommandDeleteDatabase() {
    super("database.drop");
  }

  @Override
  public boolean execute(final OHttpRequest iRequest) throws Exception {
    String[] urlParts = checkSyntax(iRequest.url, 2, "Syntax error: database/<database>");

    iRequest.data.commandInfo = "Drop database";
    iRequest.data.commandDetail = urlParts[1];

    ODatabaseDocumentTx db = null;

    try {
      final ODatabaseComplex<?> database = OServerMain.server().openDatabase("document", urlParts[1], serverUser, serverPassword);
      database.drop();

    } finally {
      if (db != null)
        db.close();
    }

    sendTextContent(iRequest, OHttpUtils.STATUS_OK_NOCONTENT_CODE, OHttpUtils.STATUS_OK_NOCONTENT_DESCRIPTION, null,
        OHttpUtils.CONTENT_TEXT_PLAIN, null);
    return false;
  }

  @Override
  public String[] getNames() {
    return NAMES;
  }
}
